@@ -1,13 +1,12 @@
 /*
  *  TOIlet        The Other Implementation’s letters
- *  Copyright (c) 2006 Sam Hocevar <sam@zoy.org>
+ *  Copyright (c) 2006 Sam Hocevar <sam@hocevar.net>
  *                All Rights Reserved
  *
- *  $Id: export.c 72 2006-11-10 07:56:55Z sam $
- *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the Do What The Fuck You Want To
- *  Public License, Version 2, as published by Sam Hocevar. See
+ *  This program is free software. It comes without any warranty, to
+ *  the extent permitted by applicable law. You can redistribute it
+ *  and/or modify it under the terms of the Do What The Fuck You Want
+ *  To Public License, Version 2, as published by Sam Hocevar. See
  *  http://sam.zoy.org/wtfpl/COPYING for more details.
  */
 
@@ -23,7 +22,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <cucul.h>
+#include <caca.h>
 
 #include "toilet.h"
 #include "export.h"
@@ -34,7 +33,7 @@ int export_list(void)
 
     printf("Available export formats:\n");
 
-    exports = cucul_get_export_list();
+    exports = caca_get_export_list();
     for(p = exports; *p; p += 2)
         printf("\"%s\": %s\n", *p, *(p + 1));
 
@@ -47,7 +46,7 @@ int export_set(context_t *cx, char const *format)
 
     cx->export = format;
 
-    exports = cucul_get_export_list();
+    exports = caca_get_export_list();
     for(p = exports; *p; p += 2)
         if(!strcmp(*p, format))
             return 0;
